@@ -2,75 +2,22 @@
 #include "liblzma_compressobj.h"
 #include "liblzma_decompressobj.h"
 #include "liblzma_options.h"
-
-PyObject *libLZMAError = NULL;
-
-bool
-CatchlibLZMAError(lzma_ret lzuerror, lzma_stream *lzus)
-{
-	bool ret = true;
-	switch(lzuerror) {
-		case LZMA_OK:
-		case LZMA_STREAM_END:
-			break;
-
-		case LZMA_PROG_ERROR:
-			PyErr_SetString(PyExc_ValueError,
-					"the lzma library has received wrong "
-					"options");
-			ret = false;
-			break;
-
-		case LZMA_DATA_ERROR:
-			PyErr_SetString(PyExc_IOError, "invalid data stream");
-			ret = false;
-			break;
-
-		case LZMA_MEM_ERROR:
-			PyErr_SetString(PyExc_MemoryError, "cannot allocate memory");
-			ret = false;
-			break;
-
-		case LZMA_BUF_ERROR:
-			if (lzus->avail_out > 0) {
-				PyErr_SetString(PyExc_IOError, "unknown BUF error");
-				ret = false;
-			}
-			break;
-
-		case LZMA_HEADER_ERROR:
-			PyErr_SetString(PyExc_RuntimeError, "invalid or unsupported header");
-			ret = false;
-			break;
-
-		case LZMA_UNSUPPORTED_CHECK:
-			PyErr_SetString(libLZMAError, "check type is unknown");
-			ret = false;
-			break;
-
-		default:
-			ret = false;
-			PyErr_SetString(libLZMAError, "unknown error!");
-			break;
-
-	}
-	return ret;
-}
+#include "liblzma_util.h"
 
 static const char __author__[] =
-"The liblzma python module was written by:\n\
+"The lzma python module was written by:\n\
 \n\
     Per Øyvind Karlsen <peroyvind@mandriva.org>\n\
 ";
 
-PyDoc_STRVAR(libLZMA_compress__doc__,
-"compress(string[format=alone, eopm=False, level=7, dictionary_size=23,\n\
+PyDoc_STRVAR(LZMA_compress__doc__,
+"compress(string [, format=alone, eopm=False, level=7, dictionary_size=23,\n\
 literal_contextbits=3 literal_pos_bits=0, pos_bits=2, mode=2, fast_bytes=128,\n\
 match_finder='bt4', match_finder_cycles=0]) -- Compress data using the given\n\
 parameters, returning a string containing the compressed data.");
 
 static PyObject *
-libLZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObject *kwargs)
+LZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObject *kwargs)
 {
 	PyObject *RetVal = NULL;
 	uint8_t *input;
@@ -107,7 +54,7 @@ libLZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObjec
 		alone.uncompressed_size = (uint64_t)length;
 
 	lzuerror = lzma_alone_encoder(lzus, &alone);
-	if(!CatchlibLZMAError(lzuerror, lzus))
+	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 
 	lzus->avail_in = (size_t)length;
@@ -119,7 +66,7 @@ libLZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObjec
 	lzuerror = lzma_code(lzus, LZMA_FINISH);
 	Py_END_ALLOW_THREADS
 
-	if(!CatchlibLZMAError(lzuerror, lzus))
+	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 	
 	lzma_end(lzus);
@@ -135,17 +82,17 @@ libLZMA_compress(__attribute__((unused)) PyObject *self, PyObject *args, PyObjec
 	return NULL;
 }
 
-PyDoc_STRVAR(libLZMA_decompress__doc__,
+PyDoc_STRVAR(LZMA_decompress__doc__,
 "decompress(string[, bufsize]) -- Return decompressed string.\n\
 \n\
 Optional arg bufsize is the initial output buffer size.");
 
 static PyObject *
-libLZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
+LZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 {
 	PyObject *result_str = NULL;
 	uint8_t *input;
-	Py_ssize_t length, r_strlen=DEFAULTALLOC;
+	Py_ssize_t length, r_strlen = SMALLCHUNK;
 	lzma_ret lzuerror;
 	lzma_stream _lzus;
 	lzma_stream *lzus = &_lzus;
@@ -167,7 +114,7 @@ libLZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 	lzus->next_in = (uint8_t *)input;
 	lzuerror = lzma_auto_decoder(lzus, 0, 0);
 
-	if(!CatchlibLZMAError(lzuerror, lzus))
+	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 
 	while (lzuerror != LZMA_STREAM_END){
@@ -175,7 +122,7 @@ libLZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 		lzuerror=lzma_code(lzus, LZMA_RUN);
 		Py_END_ALLOW_THREADS
 
-		if(!CatchlibLZMAError(lzuerror, lzus))
+		if(!Util_CatchLZMAError(lzuerror, lzus))
 			goto error;
 		if(lzuerror == LZMA_STREAM_END)
 			break;
@@ -200,14 +147,14 @@ libLZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args)
 	return NULL;
 }
 
-PyDoc_STRVAR(libLZMA_crc32__doc__,
+PyDoc_STRVAR(LZMA_crc32__doc__,
 "crc32(string[, start]) -- Compute a CRC-32 checksum of string.\n\
 \n\
 An optional starting value can be specified. The returned checksum is\n\
 an integer.");
 
 static PyObject *
-libLZMA_crc32(__attribute__((unused)) PyObject *self, PyObject *args)
+LZMA_crc32(__attribute__((unused)) PyObject *self, PyObject *args)
 {
 	uint32_t crc32val = lzma_crc32(NULL, (size_t)0,  (uint32_t)0);
     	uint8_t *buf;
@@ -218,14 +165,14 @@ libLZMA_crc32(__attribute__((unused)) PyObject *self, PyObject *args)
     	return PyInt_FromLong((long)crc32val);
 }
 
-PyDoc_STRVAR(libLZMA_crc64__doc__,
+PyDoc_STRVAR(LZMA_crc64__doc__,
 "crc64(string[, start]) -- Compute a CRC-64 checksum of string.\n\
 \n\
 An optional starting value can be specified.  The returned checksum is\n\
 an integer.");
 
 static PyObject *
-libLZMA_crc64(__attribute__((unused)) PyObject *self, PyObject *args)
+LZMA_crc64(__attribute__((unused)) PyObject *self, PyObject *args)
 {
 	uint64_t crc64val = lzma_crc64(NULL, (size_t)0, (uint64_t)0);
     	uint8_t *buf;
@@ -236,20 +183,20 @@ libLZMA_crc64(__attribute__((unused)) PyObject *self, PyObject *args)
     	return PyLong_FromUnsignedLongLong(crc64val);
 }
 
-static PyMethodDef liblzma_methods[] = {
-	{"compress", (PyCFunction)libLZMA_compress,
-		METH_VARARGS|METH_KEYWORDS, libLZMA_compress__doc__},
-    	{"crc32", (PyCFunction)libLZMA_crc32,
-		METH_VARARGS, libLZMA_crc32__doc__},
-    	{"crc64", (PyCFunction)libLZMA_crc64,
-		METH_VARARGS, libLZMA_crc64__doc__},
-	{"decompress", (PyCFunction)libLZMA_decompress,
-		METH_VARARGS, libLZMA_decompress__doc__},
+static PyMethodDef lzma_methods[] = {
+	{"compress", (PyCFunction)LZMA_compress,
+		METH_VARARGS|METH_KEYWORDS, LZMA_compress__doc__},
+    	{"crc32", (PyCFunction)LZMA_crc32,
+		METH_VARARGS, LZMA_crc32__doc__},
+    	{"crc64", (PyCFunction)LZMA_crc64,
+		METH_VARARGS, LZMA_crc64__doc__},
+	{"decompress", (PyCFunction)LZMA_decompress,
+		METH_VARARGS, LZMA_decompress__doc__},
 	{0, 0, 0, 0}
 };
 
-PyDoc_STRVAR(liblzma_module_documentation,
-"The python liblzma module provides a comprehensive interface for\n\
+PyDoc_STRVAR(lzma_module_documentation,
+"The python lzma module provides a comprehensive interface for\n\
 the lzma compression library. It implements one shot (de)compression\n\
 functions, CRC-32 & CRC-64 checksum copmutations, types for sequential\n\
 (de)compression, and advanced options for lzma compression.\n\
@@ -262,33 +209,38 @@ initlzma(void)
 {
 	PyObject *m, *ver, *optionsSingleton;
 	char verstring[10], major, minor[5], micro[5], *s;
-    	libLZMAComp_Type.ob_type = &PyType_Type;
-    	libLZMADecomp_Type.ob_type = &PyType_Type;
+    	LZMAComp_Type.ob_type = &PyType_Type;
+    	LZMADecomp_Type.ob_type = &PyType_Type;
+    	LZMAFile_Type.ob_type = &PyType_Type;
+
 	
-    	m = Py_InitModule3("lzma", liblzma_methods,
- 			liblzma_module_documentation);
+    	m = Py_InitModule3("lzma", lzma_methods,
+ 			lzma_module_documentation);
     	if (m == NULL)
 		return;
 	
-	optionsSingleton = PyType_GenericNew(&libLZMAOptions_Type, NULL, NULL);
+	optionsSingleton = PyType_GenericNew(&LZMAOptions_Type, NULL, NULL);
 	
-	if(PyType_Ready(&libLZMAOptions_Type) < 0)
+	if(PyType_Ready(&LZMAOptions_Type) < 0)
 		return;
 
-	libLZMAError = PyErr_NewException("libLZMA.error", NULL, NULL);
-    	if (libLZMAError != NULL) {
-		Py_INCREF(libLZMAError);
-		PyModule_AddObject(m, "error", libLZMAError);
+	LZMAError = PyErr_NewException("LZMA.error", NULL, NULL);
+    	if (LZMAError != NULL) {
+		Py_INCREF(LZMAError);
+		PyModule_AddObject(m, "error", LZMAError);
     	}
     
-	Py_INCREF(&libLZMAOptions_Type);
-	PyModule_AddObject(m, "LZMAOptions", (PyObject *)&libLZMAOptions_Type);
+	Py_INCREF(&LZMAOptions_Type);
+	PyModule_AddObject(m, "LZMAOptions", (PyObject *)&LZMAOptions_Type);
 
-	Py_INCREF(&libLZMAComp_Type);
-	PyModule_AddObject(m, "LZMACompressor", (PyObject *)&libLZMAComp_Type);
+	Py_INCREF(&LZMAComp_Type);
+	PyModule_AddObject(m, "LZMACompressor", (PyObject *)&LZMAComp_Type);
 
-	Py_INCREF(&libLZMADecomp_Type);
-	PyModule_AddObject(m, "LZMADecompressor", (PyObject *)&libLZMADecomp_Type);
+	Py_INCREF(&LZMADecomp_Type);
+	PyModule_AddObject(m, "LZMADecompressor", (PyObject *)&LZMADecomp_Type);
+
+	Py_INCREF(&LZMAFile_Type);
+	PyModule_AddObject(m, "LZMAFile", (PyObject *)&LZMAFile_Type);
 
 	PyModule_AddObject(m, "options", optionsSingleton);
     	PyModule_AddIntConstant(m, "LZMA_RUN", (ulong)LZMA_RUN);
