@@ -1,5 +1,6 @@
 #ifndef LIBLZMA_H
 #define LIBLZMA_H 1
+
 /* To handle length as ssize_t in stead of int, otherwise we'd either have to
  * use the internal _PyArg_ParseTuple_SizeT function to avoid screwups
  */
@@ -43,17 +44,6 @@ typedef unsigned long ulong;
 #endif
 #endif
 
-#if BUFSIZ <= 1024
-#define DEFAULTALLOC 8192
-#else
-#define	DEFAULTALLOC BUFSIZ
-#endif
-
 #define INITCHECK if (!self->is_initialised) {	PyErr_Format(PyExc_RuntimeError, "%s object not initialised!", self->ob_type->tp_name);	return NULL; }
 
-extern PyObject *libLZMAError;
-
-bool CatchlibLZMAError(lzma_ret lzuerror, lzma_stream *lzus);
-
-
 #endif /* LIBLZMA_H */
