@@ -1,7 +1,8 @@
 #include "liblzma_compressobj.h"
 #include "liblzma_options.h"
+#include "liblzma_util.h"
 
-PyDoc_STRVAR(libLZMAComp_compress__doc__,
+PyDoc_STRVAR(LZMAComp_compress__doc__,
 "compress(data) -- Feed the compressor object with data to compress sequently.\n\
 This function will return the header for the compressed string for the first\n\
 input provided, this header will be needed to concatenate with the rest of\n\
@@ -9,9 +10,9 @@ the stream when flushing to have a proper stream able to be decompressed\n\
 again.\n");
 
 static PyObject *
-libLZMAComp_compress(libLZMACompObject *self, PyObject *args)
+LZMAComp_compress(LZMACompObject *self, PyObject *args)
 {
-	Py_ssize_t inplen, length = DEFAULTALLOC;
+	Py_ssize_t inplen, length = SMALLCHUNK;
     	uint8_t *input;
     	uint64_t start_total_out;
 	PyObject *RetVal = NULL;
@@ -49,7 +50,7 @@ libLZMAComp_compress(libLZMACompObject *self, PyObject *args)
 		lzus->next_out = (uint8_t *)PyString_AS_STRING(RetVal) + length;
 		lzus->avail_out = (size_t)length;
 		length = length << 1;
-		if(!CatchlibLZMAError(lzuerror, lzus))
+		if(!Util_CatchLZMAError(lzuerror, lzus))
 			goto error;
 	}
 
@@ -64,7 +65,7 @@ libLZMAComp_compress(libLZMACompObject *self, PyObject *args)
 	return NULL;
 }
 
-PyDoc_STRVAR(libLZMAComp_flush__doc__,
+PyDoc_STRVAR(LZMAComp_flush__doc__,
 "flush( [mode] ) -- Return a string containing any remaining compressed data.\n\
 \n\
 mode can be one of the constants LZMA_SYNC_FLUSH, LZMA_FULL_FLUSH, LZMA_FINISH; the\n\
@@ -73,9 +74,9 @@ If mode == LZMA_FINISH, the compressor object can no longer be used after\n\
 calling the flush() method.  Otherwise, more data can still be compressed.\n");
 
 static PyObject *
-libLZMAComp_flush(libLZMACompObject *self, PyObject *args)
+LZMAComp_flush(LZMACompObject *self, PyObject *args)
 {
-	Py_ssize_t length = DEFAULTALLOC;
+	Py_ssize_t length = SMALLCHUNK;
     	PyObject * RetVal = NULL;
 	uint8_t flushmode = LZMA_FINISH;
     	uint64_t start_total_out;
@@ -95,7 +96,7 @@ libLZMAComp_flush(libLZMACompObject *self, PyObject *args)
 	switch(flushmode){
 		case(LZMA_SYNC_FLUSH):
 		case(LZMA_FULL_FLUSH):
-			PyErr_Format(libLZMAError, "%d is not supported as flush mode for LZMA_Alone format", flushmode);
+			PyErr_Format(LZMAError, "%d is not supported as flush mode for LZMA_Alone format", flushmode);
 			goto error;
 			/* Flushing with LZMA_RUN is a no-op, so there's no point in
 			 * doing any work at all; just return an empty string.
@@ -127,7 +128,7 @@ libLZMAComp_flush(libLZMACompObject *self, PyObject *args)
 		lzus->next_out = (uint8_t *)PyString_AS_STRING(RetVal) + length;
 		lzus->avail_out = (size_t)length;
 		length = length << 1;
-		if(!CatchlibLZMAError(lzuerror, lzus))
+		if(!Util_CatchLZMAError(lzuerror, lzus))
 			goto error;
     }
 
@@ -142,7 +143,7 @@ error:
     return RetVal;
 }
 
-PyDoc_STRVAR(libLZMAComp_reset__doc__,
+PyDoc_STRVAR(LZMAComp_reset__doc__,
 "reset([format='alone', level=7, dictionary_size=23, literal_contextbits=3,\n\
 literal_pos_bits=0, pos_bits=2, mode=2, fast_bytes=128, match_finder='bt4',\n\
 match_finder_cycles=0]) -- Resets the compression object keeping the\n\
@@ -150,7 +151,7 @@ compression settings. These existing settings can be overriden by providing\n\
 keyword settings.");
 
 static PyObject *
-libLZMAComp_reset(libLZMACompObject *self, __attribute__((unused)) PyObject *args, PyObject *kwargs)
+LZMAComp_reset(LZMACompObject *self, __attribute__((unused)) PyObject *args, PyObject *kwargs)
 {
 	PyObject *result=NULL;
 	lzma_stream *lzus = &self->lzus;
@@ -159,7 +160,7 @@ libLZMAComp_reset(libLZMACompObject *self, __attribute__((unused)) PyObject *arg
 	INITCHECK
 	if(!init_lzma_options("reset", kwargs, &self->alone.lzma))
 		return NULL;
-	self->lzma_options = libLZMA_options_get(self->alone.lzma);
+	self->lzma_options = LZMA_options_get(self->alone.lzma);
 
 
 	ACQUIRE_LOCK(self);
@@ -167,7 +168,7 @@ libLZMAComp_reset(libLZMACompObject *self, __attribute__((unused)) PyObject *arg
 		lzma_end(lzus);
 	
 	lzuerror = lzma_alone_encoder(lzus, &self->alone);
-	if(!CatchlibLZMAError(lzuerror, lzus))
+	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 	self->running = true;
 
@@ -178,35 +179,35 @@ libLZMAComp_reset(libLZMACompObject *self, __attribute__((unused)) PyObject *arg
 	return result;
 }
 
-PyDoc_STRVAR(libLZMAComp_lzma_options__doc__,
+PyDoc_STRVAR(LZMAComp_lzma_options__doc__,
 "Dictionary containing the lzma encoder options.");
 
-static PyMemberDef libLZMAComp_members[] = {
-	{"lzma_options", T_OBJECT, offsetof(libLZMACompObject, lzma_options),
-		RO, libLZMAComp_lzma_options__doc__},
+static PyMemberDef LZMAComp_members[] = {
+	{"lzma_options", T_OBJECT, offsetof(LZMACompObject, lzma_options),
+		RO, LZMAComp_lzma_options__doc__},
 	{NULL, 0, 0, 0, NULL}	/* Sentinel */
 };
 
-static PyMethodDef libLZMAComp_methods[] =
+static PyMethodDef LZMAComp_methods[] =
 {
-	{"compress", (PyCFunction)libLZMAComp_compress, METH_VARARGS,
-		libLZMAComp_compress__doc__},
-    	{"flush", (PyCFunction)libLZMAComp_flush, METH_VARARGS,
-		libLZMAComp_flush__doc__},
-    	{"reset", (PyCFunction)libLZMAComp_reset, METH_VARARGS | METH_KEYWORDS,
-		libLZMAComp_reset__doc__},
+	{"compress", (PyCFunction)LZMAComp_compress, METH_VARARGS,
+		LZMAComp_compress__doc__},
+    	{"flush", (PyCFunction)LZMAComp_flush, METH_VARARGS,
+		LZMAComp_flush__doc__},
+    	{"reset", (PyCFunction)LZMAComp_reset, METH_VARARGS | METH_KEYWORDS,
+		LZMAComp_reset__doc__},
     	{0, 0, 0, 0}
 };
 
 static int8_t
-libLZMAComp_init(libLZMACompObject *self, __attribute__((unused)) PyObject *args, PyObject *kwargs)
+LZMAComp_init(LZMACompObject *self, __attribute__((unused)) PyObject *args, PyObject *kwargs)
 {
 	lzma_stream *lzus = &self->lzus;
 	lzma_ret lzuerror;
 
 	if(!init_lzma_options("LZMACompressor", kwargs, &self->alone.lzma))
 		goto error;
-	self->lzma_options = libLZMA_options_get(self->alone.lzma);
+	self->lzma_options = LZMA_options_get(self->alone.lzma);
 
 #ifdef WITH_THREAD
 	self->lock = PyThread_allocate_lock();
@@ -217,7 +218,7 @@ libLZMAComp_init(libLZMACompObject *self, __attribute__((unused)) PyObject *args
 #endif
 
 	lzuerror = lzma_alone_encoder(lzus, &self->alone);
-	if(!CatchlibLZMAError(lzuerror, lzus))
+	if(!Util_CatchLZMAError(lzuerror, lzus))
 		goto error;
 
 	self->is_initialised = true;
@@ -236,10 +237,10 @@ libLZMAComp_init(libLZMACompObject *self, __attribute__((unused)) PyObject *args
 }
 
 static PyObject *
-libLZMACompObject_new(PyTypeObject *type, __attribute__((unused)) PyObject *args, __attribute__((unused)) PyObject *kwargs)
+LZMACompObject_new(PyTypeObject *type, __attribute__((unused)) PyObject *args, __attribute__((unused)) PyObject *kwargs)
 {
-	libLZMACompObject *self;
-	self = (libLZMACompObject *)type->tp_alloc(type, 0);
+	LZMACompObject *self;
+	self = (LZMACompObject *)type->tp_alloc(type, 0);
 	if (self != NULL){
 		self->is_initialised = false;
 		self->running = false;
@@ -254,7 +255,7 @@ libLZMACompObject_new(PyTypeObject *type, __attribute__((unused)) PyObject *args
 }
 
 static void
-libLZMAComp_dealloc(libLZMACompObject *self)
+LZMAComp_dealloc(LZMACompObject *self)
 {
 #ifdef WITH_THREAD
 	if (self->lock)
@@ -266,7 +267,7 @@ libLZMAComp_dealloc(libLZMACompObject *self)
     	self->ob_type->tp_free((PyObject*)self);
 }
 
-PyDoc_STRVAR(libLZMAComp__doc__,
+PyDoc_STRVAR(LZMAComp__doc__,
 "LZMACompressor([format='alone', level=7, dictionary_size=23, literal_contextbits=3,\n\
 literal_pos_bits=0, pos_bits=2, mode=2, fast_bytes=128, match_finder='bt4',\n\
 match_finder_cycles=0]) -- Return a compressor object.\n\
@@ -274,13 +275,13 @@ Create a new compressor object. This object may be used to compress\n\
 data sequentially. If you want to compress data in one shot, use the\n\
 compress() function instead.\n");
 
-PyTypeObject libLZMAComp_Type = {
+PyTypeObject LZMAComp_Type = {
 	PyObject_HEAD_INIT(NULL)
 	0,						/*ob_size*/
-	"liblzma.LZMACompressor",			/*tp_name*/
-	sizeof(libLZMACompObject),			/*tp_basicsize*/
+	"lzma.LZMACompressor",				/*tp_name*/
+	sizeof(LZMACompObject),				/*tp_basicsize*/
 	0,						/*tp_itemsize*/
-	(destructor)libLZMAComp_dealloc,		/*tp_dealloc*/
+	(destructor)LZMAComp_dealloc,			/*tp_dealloc*/
 	0,						/*tp_print*/
 	0,						/*tp_getattr*/
 	0,						/*tp_setattr*/
@@ -296,24 +297,24 @@ PyTypeObject libLZMAComp_Type = {
 	PyObject_GenericSetAttr,			/*tp_setattro*/
 	0,						/*tp_as_buffer*/
 	Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,		/*tp_flags*/
-	libLZMAComp__doc__,         			/*tp_doc*/
+	LZMAComp__doc__,         			/*tp_doc*/
 	0,						/*tp_traverse*/
 	0,						/*tp_clear*/
 	0,						/*tp_richcompare*/
 	0,						/*tp_weaklistoffset*/
 	0,						/*tp_iter*/
 	0,						/*tp_iternext*/
-	libLZMAComp_methods,				/*tp_methods*/
-	libLZMAComp_members,				/*tp_members*/
+	LZMAComp_methods,				/*tp_methods*/
+	LZMAComp_members,				/*tp_members*/
 	0,						/*tp_getset*/
 	0,						/*tp_base*/
 	0,						/*tp_dict*/
 	0,						/*tp_descr_get*/
 	0,						/*tp_descr_set*/
 	0,						/*tp_dictoffset*/
-	(initproc)libLZMAComp_init,			/*tp_init*/
+	(initproc)LZMAComp_init,			/*tp_init*/
 	PyType_GenericAlloc,				/*tp_alloc*/
-	libLZMACompObject_new,				/*tp_new*/
+	LZMACompObject_new,				/*tp_new*/
 	_PyObject_Del,					/*tp_free*/
 	0,						/*tp_is_gc*/
 	0,						/*tp_bases*/
