@@ -1,5 +1,6 @@
 #ifndef LIBLZMA_COMPRESSOBJ_H
 #define LIBLZMA_COMPRESSOBJ_H 1
+
 #include "liblzma.h"
 #include <structmember.h>
 
@@ -13,8 +14,8 @@ typedef struct
 #ifdef WITH_THREAD
 	PyThread_type_lock lock;
 #endif
-} libLZMACompObject;
+} LZMACompObject;
 
-extern PyTypeObject libLZMAComp_Type;
+extern PyTypeObject LZMAComp_Type;
 
 #endif /* LIBLZMA_COMPRESSOBJ_H */
