@@ -1,5 +1,6 @@
 #ifndef LIBLZMA_DECOMPRESSOBJ_H
 #define LIBLZMA_DECOMPRESSOBJ_H 1
+
 #include "liblzma.h"
 #include <structmember.h>
 
@@ -14,7 +15,8 @@ typedef struct
 #ifdef WITH_THREAD
 	PyThread_type_lock lock;
 #endif
-} libLZMADecompObject;
+} LZMADecompObject;
+
+extern PyTypeObject LZMADecomp_Type;
 
-extern PyTypeObject libLZMADecomp_Type;
 #endif /* LIBLZMA_DECOMPRESSOBJ_H */
