@@ -1,5 +1,6 @@
 #ifndef LIBLZMA_OPTIONS_H
 #define LIBLZMA_OPTIONS_H 1
+
 #include "liblzma.h"
 #include <structmember.h>
 
@@ -7,7 +8,7 @@
 static inline bool check_range(uint32_t x, uint32_t a, uint32_t b){
 	return (x < a || x > b);
 }
-#define MEMBER_DESCRIPTOR(name, type, variable, text) (PyMemberDef){name, type, offsetof(libLZMAOptionsObject, variable), RO, PyString_AsString(PyString_Format(PyString_FromString((char*)text), (PyObject*)self->variable))}
+#define MEMBER_DESCRIPTOR(name, type, variable, text) (PyMemberDef){name, type, offsetof(LZMAOptionsObject, variable), RO, PyString_AsString(PyString_Format(PyString_FromString((char*)text), (PyObject*)self->variable))}
 
 #define	LZMA_BEST_SPEED 1
 #define	LZMA_BEST_COMPRESSION 9
@@ -32,12 +33,11 @@ typedef struct
 	PyObject *match_finder_dict;
 	PyObject *match_finder;
 	PyObject *match_finder_cycles;
-} libLZMAOptionsObject;
+} LZMAOptionsObject;
 
-extern PyTypeObject libLZMAOptions_Type;
+extern PyTypeObject LZMAOptions_Type;
 
 bool init_lzma_options(const char *funcName, PyObject *kwargs, lzma_options_lzma *options);
-PyObject *libLZMA_options_get(lzma_options_lzma lzma_options);
+PyObject *LZMA_options_get(lzma_options_lzma lzma_options);
 
 #endif /* LIBLZMA_OPTIONS_H */
-
